# libpythonpro
Módulo para exemplificar construção de projetos Python no curso PyTools - PythonPro

Nesse curso é ensinado como contribuir com projetos de código aberto.

Link para o Curso [Python Pro](https://pythonpro.com.br/)


[![Updates](https://pyup.io/repos/github/r-trevisan/libpythonpro/shield.svg)](https://pyup.io/repos/github/r-trevisan/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/r-trevisan/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/r-trevisan/libpythonpro/)

Suportada versão 3.9 de Python

Para instalar:

`python3 -m venv .venv`

`.venv/Scripts/activate`

`pip install -r requirements-dev.txt`


Para conferir qualidade de código:

`flake8`

Tópicos a serem abordados:

1. Git
2. Virtualenv
3. Pip